@@ -10,37 +10,38 @@
 
 
 from preggy import expect
+from tornado.testing import gen_test
+
 from tests.base import FilterTestCase
 from thumbor.point import FocalPoint
 
 
 class RedEyeFilterTestCase(FilterTestCase):
-    def test_redeye_passthrough_when_no_face_points(self):
-        image = self.get_filtered(
-            'redeye.png',
-            'thumbor.filters.redeye',
-            'red_eye()'
+    @gen_test
+    async def test_redeye_passthrough_when_no_face_points(self):
+        image = await self.get_filtered(
+            "redeye.png", "thumbor.filters.redeye", "red_eye()"
         )
 
-        expected = self.get_fixture('redeye.png')
+        expected = self.get_fixture("redeye.png")
 
         ssim = self.get_ssim(image, expected)
         expect(ssim).to_be_greater_than(0.99)
 
-    def test_redeye_applied(self):
-        expected = self.get_fixture('redeye_applied.png')
+    @gen_test
+    async def test_redeye_applied(self):
+        expected = self.get_fixture("redeye_applied.png")
 
         def config_context(context):
             image_w, image_h = expected.size[0], expected.size[1]
-            point = FocalPoint.from_square(50, 50, image_w - 100, image_h - 100, origin='Face Detection')
+            point = FocalPoint.from_square(
+                50, 50, image_w - 100, image_h - 100, origin="Face Detection"
+            )
 
             context.request.focal_points = [point]
 
-        image = self.get_filtered(
-            'redeye.png',
-            'thumbor.filters.redeye',
-            'red_eye()',
-            config_context
+        image = await self.get_filtered(
+            "redeye.png", "thumbor.filters.redeye", "red_eye()", config_context
         )
 
         ssim = self.get_ssim(image, expected)
