@@ -9,14 +9,18 @@
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
 
 from preggy import expect
+from tornado.testing import gen_test
 
 from tests.base import FilterTestCase
 
 
 class RGBFilterTestCase(FilterTestCase):
-    def test_rgb_filter(self):
-        image = self.get_filtered('source.jpg', 'thumbor.filters.rgb', 'rgb(10,2,4)')
-        expected = self.get_fixture('rgb.jpg')
+    @gen_test
+    async def test_rgb_filter(self):
+        image = await self.get_filtered(
+            "source.jpg", "thumbor.filters.rgb", "rgb(10,2,4)"
+        )
+        expected = self.get_fixture("rgb.jpg")
 
         ssim = self.get_ssim(image, expected)
         expect(ssim).to_be_greater_than(0.98)
