@@ -8,58 +8,45 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
 
-from unittest import TestCase
-import mock
 
+from libthumbor.url import Url
 from preggy import expect
 
-from thumbor.app import (
-    ThumborServiceApp
-)
-from thumbor.url import Url
+from thumbor.app import ThumborServiceApp
+from thumbor.testing import TestCase
 
 
 class AppTestCase(TestCase):
     def test_can_create_app(self):
-        ctx = mock.Mock()
-        app = ThumborServiceApp(ctx)
+        app = ThumborServiceApp(self.context)
         expect(app).not_to_be_null()
-        expect(app.context).to_equal(ctx)
+        expect(app.context).to_equal(self.context)
 
     def test_can_get_handlers(self):
-        ctx = mock.Mock(
-            config=mock.Mock(
-                UPLOAD_ENABLED=False,
-                USE_BLACKLIST=False,
-                HEALTHCHECK_ROUTE=r'/healthcheck',
-            )
-        )
+        ctx = self.get_context()
+        ctx.config.UPLOAD_ENABLED = False
+        ctx.config.USE_BLACKLIST = False
+        ctx.config.HEALTHCHECK_ROUTE = "/health"
         app = ThumborServiceApp(ctx)
 
         handlers = app.get_handlers()
         expect(handlers).to_length(2)
-        expect(handlers[0][0]).to_equal(r'/healthcheck')
+        expect(handlers[0][0]).to_equal(r"/health")
         expect(handlers[1][0]).to_equal(Url.regex())
 
     def test_can_get_handlers_with_upload(self):
-        ctx = mock.Mock(
-            config=mock.Mock(
-                UPLOAD_ENABLED=True,
-                USE_BLACKLIST=False,
-            )
-        )
+        ctx = self.get_context()
+        ctx.config.UPLOAD_ENABLED = True
+        ctx.config.USE_BLACKLIST = False
         app = ThumborServiceApp(ctx)
 
         handlers = app.get_handlers()
         expect(handlers).to_length(4)
 
     def test_can_get_handlers_with_blacklist(self):
-        ctx = mock.Mock(
-            config=mock.Mock(
-                UPLOAD_ENABLED=False,
-                USE_BLACKLIST=True,
-            )
-        )
+        ctx = self.get_context()
+        ctx.config.UPLOAD_ENABLED = False
+        ctx.config.USE_BLACKLIST = True
         app = ThumborServiceApp(ctx)
 
         handlers = app.get_handlers()
