@@ -7,7 +7,8 @@
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
-'''This is the main module in thumbor'''
 
-__version__ = "6.7.0"
-__release_date__ = "17-Jan-2019"
+"""This is the main module in thumbor"""
+
+__version__ = "7.0.10"
+__release_date__ = "20-May-2022"
