@@ -13,4 +13,4 @@ from thumbor.detectors.queued_detector import QueuedDetector
 
 
 class Detector(QueuedDetector):
-    detection_type = 'all'
+    detection_type = "all"
