@@ -8,9 +8,17 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 globo.com thumbor@googlegroups.com
 
-import piexif
+# This is a base class, it makes sense to have many public methods and instance attributes
+# pylint: disable=attribute-defined-outside-init,too-many-public-methods,unused-argument,too-many-instance-attributes,broad-except
+
+import re
 from xml.etree.ElementTree import ParseError
 
+from thumbor.engines.extensions.exif_orientation_editor import (
+    ExifOrientationEditor,
+)
+from thumbor.utils import EXTENSION, logger
+
 try:
     import cairosvg
 except ImportError:
@@ -18,25 +26,28 @@ except ImportError:
 
 try:
     from pyexiv2 import ImageMetadata
+
     METADATA_AVAILABLE = True
 except ImportError:
     METADATA_AVAILABLE = False
 
-import re
-
-from thumbor.utils import logger, EXTENSION
 
 WEBP_SIDE_LIMIT = 16383
 
-SVG_RE = re.compile(r'<svg\s[^>]*([\"\'])http[^\"\']*svg[^\"\']*', re.I)
+SVG_RE = re.compile(
+    b"<svg\s[^>]*([\"'])http[^\"']*svg[^\"']*",  # pylint: disable=anomalous-backslash-in-string
+    re.I,
+)
 
 
-class EngineResult(object):
+class EngineResult:
 
-    COULD_NOT_LOAD_IMAGE = 'could not load image'
+    COULD_NOT_LOAD_IMAGE = "could not load image"
 
-    def __init__(self, buffer_=None, successful=True, error=None, metadata=dict()):
-        '''
+    def __init__(
+        self, buffer_=None, successful=True, error=None, metadata=None
+    ):
+        """
         :param buffer: The media buffer
 
         :param successful: True when the media has been read by the engine.
@@ -47,7 +58,10 @@ class EngineResult(object):
 
         :param metadata: Dictionary of metadata about the buffer
         :type metadata: dict
-        '''
+        """
+
+        if metadata is None:
+            metadata = {}
 
         self.buffer = buffer_
         self.successful = successful
@@ -56,7 +70,6 @@ class EngineResult(object):
 
 
 class MultipleEngine:
-
     def __init__(self, source_engine):
         self.frame_engines = []
         self.source_engine = source_engine
@@ -73,7 +86,8 @@ class MultipleEngine:
     def read(self, extension=None, quality=None):
         return self.source_engine.read_multiple(
             [frame_engine.image for frame_engine in self.frame_engines],
-            extension)
+            extension,
+        )
 
     def size(self):
         return self.frame_engines[0].size
@@ -84,11 +98,11 @@ class MultipleEngine:
             for frame_engine in self.frame_engines:
                 result.append(getattr(frame_engine, name)(*args, **kwargs))
             return result
+
         return exec_func
 
 
-class BaseEngine(object):
-
+class BaseEngine:
     def __init__(self, context):
         self.context = context
         self.image = None
@@ -101,33 +115,46 @@ class BaseEngine(object):
 
     @classmethod
     def get_mimetype(cls, buffer):
-        if buffer.startswith('GIF8'):
-            return 'image/gif'
-        elif buffer.startswith('\x89PNG\r\n\x1a\n'):
-            return 'image/png'
-        elif buffer.startswith('\xff\xd8'):
-            return 'image/jpeg'
-        elif buffer.startswith('WEBP', 8):
-            return 'image/webp'
-        elif buffer.startswith('\x00\x00\x00\x0c'):
-            return 'image/jp2'
-        elif buffer.startswith('\x00\x00\x00 ftyp'):
-            return 'video/mp4'
-        elif buffer.startswith('\x1aE\xdf\xa3'):
-            return 'video/webm'
-        elif buffer.startswith('\x49\x49\x2A\x00') or buffer.startswith('\x4D\x4D\x00\x2A'):
-            return 'image/tiff'
-        elif SVG_RE.search(buffer[:2048].replace(b'\0', '')):
-            return 'image/svg+xml'
+        img_mime = None
+
+        if buffer.startswith(b"GIF8"):
+            img_mime = "image/gif"
+        elif buffer.startswith(b"\x89PNG\r\n\x1a\n"):
+            img_mime = "image/png"
+        elif buffer.startswith(b"\xff\xd8"):
+            img_mime = "image/jpeg"
+        elif buffer.startswith(b"WEBP", 8):
+            img_mime = "image/webp"
+        elif buffer.startswith(b"\x00\x00\x00\x0c"):
+            img_mime = "image/jp2"
+        elif buffer.startswith(b"\x00\x00\x00 ftyp"):
+            img_mime = "video/mp4"
+        elif buffer.startswith(b"\x1aE\xdf\xa3"):
+            img_mime = "video/webm"
+        elif buffer.startswith(b"\x49\x49\x2A\x00") or buffer.startswith(
+            b"\x4D\x4D\x00\x2A"
+        ):
+            img_mime = "image/tiff"
+        elif SVG_RE.search(buffer[:2048].replace(b"\0", b"")):
+            img_mime = "image/svg+xml"
+
+        return img_mime
 
     def wrap(self, multiple_engine):
-        for method_name in ['resize', 'crop', 'flip_vertically',
-                            'flip_horizontally']:
+        for method_name in [
+            "resize",
+            "crop",
+            "flip_vertically",
+            "flip_horizontally",
+        ]:
             setattr(self, method_name, multiple_engine.do_many(method_name))
-        setattr(self, 'read', multiple_engine.read)
+        setattr(self, "read", multiple_engine.read)
 
     def is_multiple(self):
-        return hasattr(self, 'multiple_engine') and self.multiple_engine is not None
+        return (
+            hasattr(self, "multiple_engine")
+            and self.multiple_engine is not None
+        )
 
     def frame_engines(self):
         return self.multiple_engine.frame_engines
@@ -141,13 +168,15 @@ class BaseEngine(object):
             return buffer
 
         try:
-            buffer = cairosvg.svg2png(bytestring=buffer, dpi=self.context.config.SVG_DPI)
+            buffer = cairosvg.svg2png(  # pylint: disable=no-member
+                bytestring=buffer, dpi=self.context.config.SVG_DPI
+            )
             mime = self.get_mimetype(buffer)
-            self.extension = EXTENSION.get(mime, '.jpg')
+            self.extension = EXTENSION.get(mime, ".jpg")
         except ParseError:
             mime = self.get_mimetype(buffer)
             extension = EXTENSION.get(mime)
-            if extension is None or extension == '.svg':
+            if extension is None or extension == ".svg":
                 raise
             self.extension = extension
 
@@ -158,9 +187,9 @@ class BaseEngine(object):
 
         if extension is None:
             mime = self.get_mimetype(buffer)
-            self.extension = EXTENSION.get(mime, '.jpg')
+            self.extension = EXTENSION.get(mime, ".jpg")
 
-        if self.extension == '.svg':
+        if self.extension == ".svg":
             buffer = self.convert_svg_to_png(buffer)
 
         image_or_frames = self.create_image(buffer)
@@ -171,11 +200,12 @@ class BaseEngine(object):
             try:
                 self.metadata = ImageMetadata.from_buffer(buffer)
                 self.metadata.read()
-            except Exception as e:
-                logger.error('Error reading image metadata: %s' % e)
+            except Exception as error:  # pylint: disable=broad-except
+                logger.error("Error reading image metadata: %s", error)
 
         if self.context.config.ALLOW_ANIMATED_GIFS and isinstance(
-                image_or_frames, (list, tuple)):
+            image_or_frames, (list, tuple)
+        ):
             self.image = image_or_frames[0]
             if len(image_or_frames) > 1:
                 self.multiple_engine = MultipleEngine(self)
@@ -197,15 +227,19 @@ class BaseEngine(object):
         return self.image.size
 
     def can_convert_to_webp(self):
-        return self.size[0] <= WEBP_SIDE_LIMIT and self.size[1] <= WEBP_SIDE_LIMIT
+        return (
+            self.size[0] <= WEBP_SIDE_LIMIT and self.size[1] <= WEBP_SIDE_LIMIT
+        )
 
     def normalize(self):
         width, height = self.size
         self.source_width = width
         self.source_height = height
 
-        if width > self.context.config.MAX_WIDTH \
-                or height > self.context.config.MAX_HEIGHT:
+        if (
+            width > self.context.config.MAX_WIDTH
+            or height > self.context.config.MAX_HEIGHT
+        ):
             width_diff = width - self.context.config.MAX_WIDTH
             height_diff = height - self.context.config.MAX_HEIGHT
             if self.context.config.MAX_WIDTH and width_diff > height_diff:
@@ -214,7 +248,8 @@ class BaseEngine(object):
                 )
                 self.resize(self.context.config.MAX_WIDTH, height)
                 return True
-            elif self.context.config.MAX_HEIGHT and height_diff > width_diff:
+
+            if self.context.config.MAX_HEIGHT and height_diff > width_diff:
                 width = self.get_proportional_width(
                     self.context.config.MAX_HEIGHT
                 )
@@ -231,16 +266,15 @@ class BaseEngine(object):
         width, height = self.size
         return round(float(new_width) * height / width, 0)
 
-    def _get_exif_segment(self):
-        if (not hasattr(self, 'exif')) or self.exif is None:
+    def _get_exif_object(self):
+        if (not hasattr(self, "exif")) or self.exif is None:
             return None
 
         try:
-            exif_dict = piexif.load(self.exif)
-        except Exception:
-            logger.exception('Ignored error handling exif for reorientation')
-        else:
-            return exif_dict
+            return ExifOrientationEditor(self.exif)
+        except Exception as error:
+            logger.exception("[exif] %s", error)
+
         return None
 
     def get_orientation(self):
@@ -251,10 +285,9 @@ class BaseEngine(object):
         :return: Orientation value (1 - 8)
         :rtype: int or None
         """
-        exif_dict = self._get_exif_segment()
-        if exif_dict and piexif.ImageIFD.Orientation in exif_dict["0th"]:
-            return exif_dict["0th"][piexif.ImageIFD.Orientation]
-        return None
+        exif = self._get_exif_object()
+
+        return exif.get_orientation() if exif else None
 
     def reorientate(self, override_exif=True):
         """
@@ -264,7 +297,11 @@ class BaseEngine(object):
         :param override_exif: If the metadata should be adjusted as well.
         :type override_exif: Boolean
         """
-        orientation = self.get_orientation()
+        exif = self._get_exif_object()
+        if exif is None:
+            return
+
+        orientation = exif.get_orientation()
 
         if orientation is None:
             return
@@ -289,14 +326,11 @@ class BaseEngine(object):
             self.rotate(90)
 
         if orientation != 1 and override_exif:
-            exif_dict = self._get_exif_segment()
-            if exif_dict and piexif.ImageIFD.Orientation in exif_dict["0th"]:
-                exif_dict["0th"][piexif.ImageIFD.Orientation] = 1
-                try:
-                    self.exif = piexif.dump(exif_dict)
-                except Exception as e:
-                    msg = """[piexif] %s""" % e
-                    logger.error(msg)
+            try:
+                exif.set_orientation(1)
+                self.exif = exif.tobytes()
+            except Exception as error:
+                logger.error("[exif] %s", error)
 
     def gen_image(self, size, color):
         raise NotImplementedError()
@@ -325,7 +359,6 @@ class BaseEngine(object):
         :param degrees: Amount to rotate in degrees.
         :type amount: int
         """
-        pass
 
     def read_multiple(self, images, extension=None):
         raise NotImplementedError()
@@ -340,8 +373,8 @@ class BaseEngine(object):
         raise NotImplementedError()
 
     def get_image_mode(self):
-        """ Possible return values should be: RGB, RBG, GRB, GBR,
-            BRG, BGR, RGBA, AGBR, ...  """
+        """Possible return values should be: RGB, RBG, GRB, GBR,
+        BRG, BGR, RGBA, AGBR, ..."""
         raise NotImplementedError()
 
     def paste(self, other_engine, pos, merge=True):
@@ -359,7 +392,9 @@ class BaseEngine(object):
     def convert_to_grayscale(self, update_image=True, alpha=True):
         raise NotImplementedError()
 
-    def draw_rectangle(self, x, y, width, height):
+    def draw_rectangle(
+        self, x, y, width, height
+    ):  # pylint: disable=invalid-name
         raise NotImplementedError()
 
     def strip_icc(self):
@@ -375,6 +410,6 @@ class BaseEngine(object):
         pass
 
     def can_auto_convert_png_to_jpg(self):
-        can_convert = (self.extension == '.png' and not self.has_transparency())
+        can_convert = self.extension == ".png" and not self.has_transparency()
 
         return can_convert
