@@ -12,15 +12,14 @@ from thumbor.filters import BaseFilter, filter_method
 
 
 class Filter(BaseFilter):
-
     @filter_method(BaseFilter.DecimalNumber)
-    def proportion(self, value):
+    async def proportion(self, value):
         source_width, source_height = self.context.request.engine.size
 
         new_width = source_width * value
         new_height = source_height * value
 
-        if new_width <= 0 or new_height <= 0:
+        if new_width < 1 or new_height < 1:
             return
 
         self.engine.resize(new_width, new_height)
