@@ -12,8 +12,10 @@ from thumbor.handlers import BaseHandler
 
 
 class HealthcheckHandler(BaseHandler):
-    def get(self):
-        self.write('WORKING')
+    async def get(self):
+        self.set_header("Cache-Control", "no-cache")
+        self.write("WORKING")
 
-    def head(self, *args, **kwargs):
+    async def head(self):
+        self.set_header("Cache-Control", "no-cache")
         self.set_status(200)
